# Before `make install' is performed this script should be runnable with
# `make test'. After `make install' it should work as `perl test.pl'

#########################

# change 'tests => 1' to 'tests => last_test_to_print';

use Test;
BEGIN { plan tests => 3 };
use Regexp::Keep;
ok(1); # If we made it this far, we're ok.

#########################

# Insert your test code below, the Test module is use()ed here so read
# its man page ( perldoc Test ) for help writing this test script.

my $x;

$x = "abc.def.ghi.jkl";
$x =~ s/.*\K\..*//;
ok($x eq "abc.def.ghi");

$x = "one two three four";
$x =~ s/o+ \Kthree//g;
ok($x eq "one two  four");
